var DeckView = Backbone.View.extend({
    template: _.template($("#deck_template").html()),
    events: {
        'click #viewBtn': 'toggleSplitView'
    },
    initialize: function(options) {
        this.timer = new Timer();
        this.timer.set(config.get('frontTime'));
        this.counter = new Counter({
            hits_collection: this.collection
        });
        this.collection.on('index:next', this.moveToNext, this);
        this.collection.on('index:previous', this.moveToPrevious, this);
        this.timer.on('end', this.timerEnded, this);

        this.cardViews = this.collection.map(function(model) {
            return new CardView({
                model: model,
                parentView: this
            }).render();
        }, this);
    },
    render: function() {
        var html = this.template({
            title: config.get('title'),
            description: config.get('description'),
            cardViews: this.cardViews
        });
		
        $(this.el).append(html);

// LUCIANO - Top of the pager + help

		altezzaW = $(window).height();
		altezzaFr = (altezzaW / 2) - 50;
		this.$(".pager").css("top",altezzaFr)

		$('#help').click(function () {
			$('#dialog_help').dialog({
				title: "Guida all'uso",
				width:585,
				resizable: false,
				draggable:false,
				modal:true
			});
		});
		
//LUCIANO - End
		
        _.each(this.cardViews, function(view) {
            this.$('.cards').append(view.el);
        }, this);

        this.paginatorView = new PaginatorView({
            collection: this.collection,
            el: this.$('.pager'),
            parentView: this
        });
        this.timerView = new TimerView({
            model: this.timer,
            parentView: this,
            el: this.$('#timer')
        });

        if (config.get('counter')) {
            this.counterView = new CounterView({
                model: this.counter,
                parentView: this,
                el: this.$('#counter')
            }).render();
            this.resultsView = new ResultsView({
                model: this.counter,
                parentView: this,
                el: this.$('#results')
            });
        }

        if (config.get('splitView')) {
            this.$('#viewBtn').show();
        }
		
		if (!config.get('randomCard')) {
            this.$('#refresh').hide();
        }
		
		if (!config.get('timer')) {
            this.$('#timer').hide();
        }

        $(this.el).addClass('singleView');
        $(this.el).data('view', this);

        this.trigger('rendered');

        return this;
    },
    start: function() {
        this.currentCardView().faces['front'].showContent();
        this.currentCardView().bindSlidingIn();
        this.moveToCard(this.currentCardView(), true);
    },
    moveToPrevious: function() {
        this.currentCardView().bindSlidingIn();

        this.trigger('move:start');
        this.unloadCardAtDelta(0, 'left', false);
        this.unloadCardAtDelta(1, 'right', true);

        this.moveToCard(this.currentCardView(), true);
    },
    moveToNext: function() {
        this.currentCardView().bindSlidingIn();
        this.trigger('move:start');
        this.unloadCardAtDelta(0, 'right', false);
        this.unloadCardAtDelta(-1, 'left', true);
        this.moveToCard(this.currentCardView(), true);
    },
    moveToCard: function(card, animated) {
        if (Modernizr.csstransitions) {
			card.cssTransitionsMoveIn(animated);
        } else {
            this.marginLeftMoveIn(card, animated);
        }
    },
    marginLeftMoveIn: function(card, animated) {
        if (animated) {
            card.show();
            index = this.collection.indexOf(card.model);
            marginLeft = ($(card.el).width() + parseInt($(card.el).css('margin-right'))) * index
            $('.cards').animate({
                marginLeft: -marginLeft
            }, 700, 'easeInOutQuint', card.onEndSlideIn);
        }
    },
    unloadCardAtDelta: function(delta, direction, animated) {
        this.trigger('card:'+this.cardViewAtDelta(delta).model.get('id')+":unload", direction, animated);
    },
    cardViewAtDelta: function(delta) {
        return this.cardViews[this.collection.currentIndex+delta];
    },
    currentCardView: function() {
        return this.cardViewAtDelta(0);
    },
    timerEnded: function(e) {
        if (this.currentCardView().side == 'back') {
            this.collection.next();
        } else {
            if (config.get('flipEndTime')) {
                this.currentCardView().toggleSide();
            }
        }
    },
    toggleSplitView: function(e) {
        e.preventDefault();
        this.$('.card').removeClass('animate');
        if (!this.splitView) {

            $(this.el).removeClass('singleView').addClass('splitView');
            cardView = this.currentCardView();
			this.$('.flipCard').hide();
            this.splitView = true;
            this.trigger('splitView');
        } else {
            this.$('.face.back').hide();
            $(this.el).offset().top;
            $(this.el).removeClass('splitView').addClass('singleView');
            this.splitView = false;
			this.$('.flipCard').show();
            this.trigger('singleView');
            this.$('.face.back').css('display', '');
       }
       this.$('.card').addClass('animate');
    },
    hideCard: function(cardView) {
        cardView.hide();
    },
    showCard: function(cardView) {
        cardView.show();
    }
});
